@@ -11,6 +11,7 @@ use clap::Parser;
 use crate::BaseOptions;
 use assorted_debian_utils::{
     architectures::Architecture,
+    archive::SuiteOrCodename,
     wb::{BinNMU, SourceSpecifier, WBCommandBuilder},
 };
 
@@ -30,7 +31,7 @@ pub(crate) struct PrepareBinNMUsOptions {
     extra_depends: Option<String>,
     /// Set the suite
     #[clap(short, long, default_value = "unstable")]
-    suite: String,
+    suite: SuiteOrCodename,
     /// Set architectures for binNMUs
     #[clap(short, long)]
     architecture: Option<Vec<Architecture>>,
@@ -75,8 +76,9 @@ impl PrepareBinNMUs {
                 }
 
                 let mut source = SourceSpecifier::new(package.unwrap().as_str());
+                let version = version.unwrap().as_str().try_into()?;
                 source
-                    .with_version(version.unwrap().as_str())
+                    .with_version(&version)
                     .with_suite(&self.options.suite);
                 if let Some(architectures) = &self.options.architecture {
                     source.with_archive_architectures(architectures);
