@@ -8,9 +8,13 @@ use clap::Parser;
 use indicatif::{ProgressBar, ProgressIterator};
 use serde::{Deserialize, Serialize};
 
-use crate::{config, downloader::*, source_packages::SourcePackages, BaseOptions};
+use crate::{
+    config::{self, CacheEntries, CacheState},
+    source_packages::SourcePackages,
+    BaseOptions,
+};
 use assorted_debian_utils::{
-    architectures::RELEASE_ARCHITECTURES,
+    architectures::{Architecture, RELEASE_ARCHITECTURES},
     excuses::{self, Component, ExcusesItem, PolicyInfo, Verdict},
     wb::{BinNMU, SourceSpecifier, WBArchitecture, WBCommand, WBCommandBuilder},
 };
@@ -46,41 +50,22 @@ pub(crate) struct ProcessExcuses {
 impl ProcessExcuses {
     pub(crate) fn new(base_options: BaseOptions, options: ProcessExcusesOptions) -> Result<Self> {
         Ok(Self {
-            cache: config::Cache::new()?,
+            cache: config::Cache::new(base_options.force_download)?,
             base_options,
             options,
         })
     }
 
+    #[tokio::main]
     async fn download_to_cache(&self) -> Result<CacheState> {
-        let downloader = Downloader::new(self.base_options.force_download);
-
-        let urls = [(
-            "https://release.debian.org/britney/excuses.yaml",
-            "excuses.yaml",
-        )];
-        for (url, dst) in urls {
-            if downloader
-                .download_file(url, self.cache.get_cache_path(dst)?)
-                .await?
-                == CacheState::NoUpdate
-                && !self.base_options.force_processing
-            {
-                // if excuses.yaml did not change, there is nothing new to build
-                return Ok(CacheState::NoUpdate);
-            }
-        }
-        for architecture in RELEASE_ARCHITECTURES {
-            let url = format!(
-                "https://deb.debian.org/debian/dists/unstable/main/binary-{}/Packages.xz",
-                architecture
-            );
-            let dest = format!("Packages_{}", architecture);
-            downloader
-                .download_file(&url, self.cache.get_cache_path(&dest)?)
-                .await?;
+        if self.cache.download(&[CacheEntries::Excuses]).await? == CacheState::NoUpdate
+            && !self.base_options.force_processing
+        {
+            // if excuses.yaml did not change, there is nothing new to build
+            return Ok(CacheState::NoUpdate);
         }
 
+        self.cache.download(&[CacheEntries::Packages]).await?;
         Ok(CacheState::FreshFiles)
     }
 
@@ -124,6 +109,10 @@ impl ProcessExcuses {
             for (arch, signer) in policy_info.builtonbuildd.as_ref().unwrap().signed_by.iter() {
                 if let Some(signer) = signer {
                     if !signer.ends_with("@buildd.debian.org") {
+                        if arch == &Architecture::All {
+                            // cannot binNMU arch: all
+                            return None;
+                        }
                         archs.push(WBArchitecture::Architecture(arch.clone()));
                     }
                 }
@@ -134,7 +123,8 @@ impl ProcessExcuses {
             }
 
             let mut source_specifier = SourceSpecifier::new(&item.source);
-            source_specifier.with_version(&item.new_version);
+            let version = item.new_version.as_str().try_into().unwrap();
+            source_specifier.with_version(&version);
             if !source_packages.is_ma_same(&item.source) {
                 source_specifier.with_architectures(&archs);
             }
@@ -196,10 +186,9 @@ impl ProcessExcuses {
         Ok(())
     }
 
-    #[tokio::main]
-    pub(crate) async fn run(self) -> Result<()> {
+    pub(crate) fn run(self) -> Result<()> {
         // download excuses and Package files
-        if self.download_to_cache().await? == CacheState::NoUpdate {
+        if self.download_to_cache()? == CacheState::NoUpdate {
             // nothing to do
             return Ok(());
         }
